pub struct ShutdownHandle { /* private fields */ }Expand description
A lightweight handle that can be used to shut down a running TalkStack
from another task without holding the full stack.
Implementations
Sourceimpl ShutdownHandle
impl ShutdownHandle
Sourcepub async fn transport_closed(&self)
pub async fn transport_closed(&self)
Wait until the transport layer shuts down (e.g. serial device disconnected). Useful for detecting when the stack is no longer viable.
Sourcepub async fn graceful_shutdown(&self)
pub async fn graceful_shutdown(&self)
Close sessions gracefully (e.g. send ASP CloseSess), then stop the transport once all services confirm they are done, or after 5 seconds.